Non-parametric tests for Multiple Comparison — STAC 0.7 documentation

### Navigation

- index
- next |
- previous |
- STAC 0.7 documentation »

# Non-parametric tests for Multiple Comparison

Ranking tests

`friedman_test`(*args) |
`friedman_aligned_ranks_test`(*args) |
`quade_test`(*args) |

Post-hoc 1 vs all tests

`bonferroni_test` |
`holm_test`(ranks[, control]) |
`finner_test`(ranks[, control]) |
`hochberg_test`(ranks[, control]) |
`li_test`(ranks[, control]) |

Post-hoc all vs all tests

`nemenyi_multitest`(ranks) |
`holm_multitest`(ranks) |
`finner_multitest`(ranks) |
`hochberg_multitest`(ranks) |
`shaffer_multitest`(ranks) |

### Navigation

- index
- next |
- previous |
- STAC 0.7 documentation »